==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/costmanagement/kotlin/inputs/FileDestinationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.costmanagement.kotlin.inputs

import com.pulumi.azurenative.costmanagement.inputs.FileDestinationArgs.builder
import com.pulumi.azurenative.costmanagement.kotlin.enums.FileFormat
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Destination of the view data. This is optional. Currently only CSV format is supported.
 * @property fileFormats Destination of the view data. Currently only CSV format is supported.
 */
public data class FileDestinationArgs(
    public val fileFormats: Output<List<Either<String, FileFormat>>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.costmanagement.inputs.FileDestinationArgs> {
    override fun toJava(): com.pulumi.azurenative.costmanagement.inputs.FileDestinationArgs =
        com.pulumi.azurenative.costmanagement.inputs.FileDestinationArgs.builder()
            .fileFormats(
                fileFormats?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 ->
                            args0
                        }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                    })
                }),
            ).build()
}

/**
 * Builder for [FileDestinationArgs].
 */
@PulumiTagMarker
public class FileDestinationArgsBuilder internal constructor() {
    private var fileFormats: Output<List<Either<String, FileFormat>>>? = null

    /**
     * @param value Destination of the view data. Currently only CSV format is supported.
     */
    @JvmName("racmbwmpwjmootrr")
    public suspend fun fileFormats(`value`: Output<List<Either<String, FileFormat>>>) {
        this.fileFormats = value
    }

    @JvmName("kmviplumbrktdbrs")
    public suspend fun fileFormats(vararg values: Output<Either<String, FileFormat>>) {
        this.fileFormats = Output.all(values.asList())
    }

    /**
     * @param values Destination of the view data. Currently only CSV format is supported.
     */
    @JvmName("iryhgrttmvihequn")
    public suspend fun fileFormats(values: List<Output<Either<String, FileFormat>>>) {
        this.fileFormats = Output.all(values)
    }

    /**
     * @param value Destination of the view data. Currently only CSV format is supported.
     */
    @JvmName("alyvnlgtlgbdurvj")
    public suspend fun fileFormats(`value`: List<Either<String, FileFormat>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fileFormats = mapped
    }

    /**
     * @param values Destination of the view data. Currently only CSV format is supported.
     */
    @JvmName("ryogcffjbsfwdxdl")
    public suspend fun fileFormats(vararg values: Either<String, FileFormat>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.fileFormats = mapped
    }

    internal fun build(): FileDestinationArgs = FileDestinationArgs(
        fileFormats = fileFormats,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/costmanagement/kotlin/inputs/FileDestinationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.costmanagement.kotlin.inputs

import com.pulumi.azurenative.costmanagement.inputs.FileDestinationArgs.builder
import com.pulumi.azurenative.costmanagement.kotlin.enums.FileFormat
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Destination of the view data. This is optional. Currently only CSV format is supported.
 * @property fileFormats Destination of the view data. Currently only CSV format is supported.
 */
public data class FileDestinationArgs(
    public val fileFormats: Output<List<Either<String, FileFormat>>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.costmanagement.inputs.FileDestinationArgs> {
    override fun toJava(): com.pulumi.azurenative.costmanagement.inputs.FileDestinationArgs =
        com.pulumi.azurenative.costmanagement.inputs.FileDestinationArgs.builder()
            .fileFormats(
                fileFormats?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 ->
                            args0
                        }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                    })
                }),
            ).build()
}

/**
 * Builder for [FileDestinationArgs].
 */
@PulumiTagMarker
public class FileDestinationArgsBuilder internal constructor() {
    private var fileFormats: Output<List<Either<String, FileFormat>>>? = null

    /**
     * @param value Destination of the view data. Currently only CSV format is supported.
     */
    @JvmName("fsykvtundjisiesv")
    public suspend fun fileFormats(`value`: Output<List<Either<String, FileFormat>>>) {
        this.fileFormats = value
    }

    @JvmName("jupjunyhsjdhkaym")
    public suspend fun fileFormats(vararg values: Output<Either<String, FileFormat>>) {
        this.fileFormats = Output.all(values.asList())
    }

    /**
     * @param values Destination of the view data. Currently only CSV format is supported.
     */
    @JvmName("pbvwqdvarhwujihl")
    public suspend fun fileFormats(values: List<Output<Either<String, FileFormat>>>) {
        this.fileFormats = Output.all(values)
    }

    /**
     * @param value Destination of the view data. Currently only CSV format is supported.
     */
    @JvmName("gwabnpjlvcsxsfir")
    public suspend fun fileFormats(`value`: List<Either<String, FileFormat>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fileFormats = mapped
    }

    /**
     * @param values Destination of the view data. Currently only CSV format is supported.
     */
    @JvmName("yqruexhpuwmmsrmd")
    public suspend fun fileFormats(vararg values: Either<String, FileFormat>) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.fileFormats = mapped
    }

    internal fun build(): FileDestinationArgs = FileDestinationArgs(
        fileFormats = fileFormats,
    )
}
